pub struct Consts {
    pub consts: Vec<Const>,
}
Wrapper around a vector of Const with some helper functions.

Fields

consts: Vec<Const>

Implementations

source

impl Consts

source

pub fn new(consts: Vec<Const>) -> Self

source

pub fn find_sysno(&self, name: &str, arch: &Arch) -> Option<usize>

Try and resolve a system call number by name, like write

source

pub fn consts(&self) -> Iter<'_, Const>

Iterate over all the consts

source

pub fn push(&mut self, c: Const)

Push new value without checking if this element is new

source

pub fn find_name_arch(&self, name: &str, arch: &Arch) -> Option<&Const>

Find value based on name and architecture

source

pub fn get_arch_from_path(file: &Path) -> Result<Option<Arch>, Error>

Architecture can be specified on the filename, like: <name>_amd64.const. This function tries to extract it.

source

pub fn create_from_file(&mut self, p: &Path) -> Result<(), Error>

Parse constants from file

source

pub fn create_from_str(s: &str, arch: Option<Arch>) -> Result<Vec<Const>, Error>

Create constants from string

source

pub fn add_if_new(&mut self, c: Const) -> bool

Same as Self::push, but only add if the element is unique

source

pub fn add_vec(&mut self, consts: Vec<Const>) -> usize

Add from a vector, uses Self::add_if_new on each element

source

pub fn filter_arch(&mut self, arch: &Arch)

Remove all consts not relevant for the specified architecture.

Not necessary, but can be used to save memory.